package openfuture.legend;

import java.beans.*;
import java.awt.Image;

/**
 * Class JLegendBeanInfo is the bean information class for Legend.
 *
 * @author  Markus Giebeler
 * @version $Revision: 1.0 $
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.<p>
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.<p>
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA<br>
 * http://www.gnu.org/copyleft/lesser.html"
 */
public class JLegendBeanInfo extends SimpleBeanInfo {
  private Class beanClass = JLegend.class;
  private String iconColor16x16Filename="legend16color.gif";
  private String iconColor32x32Filename="legend32color.gif";
  private String iconMono16x16Filename="legend16mono.gif";
  private String iconMono32x32Filename="legend32mono.gif";

 /**
  * Construction
  */
  public JLegendBeanInfo() {
  }

 /**
  * get the property descriptors
  *
  * @return (PropertyDescriptor[]) the property descriptors
  */
  public PropertyDescriptor[] getPropertyDescriptors() {
    try  {
      PropertyDescriptor _borderVisible = new PropertyDescriptor("borderVisible", beanClass, "isBorderVisible", "setBorderVisible");
      PropertyDescriptor _colors = new PropertyDescriptor("colors", beanClass, "getColors", "setColors");
      PropertyDescriptor _labels = new PropertyDescriptor("labels", beanClass, "getLabels", "setLabels");
      PropertyDescriptor _orientation = new PropertyDescriptor("orientation", beanClass, "getOrientation", "setOrientation");
      PropertyDescriptor[] pds = new PropertyDescriptor[] {
	      _borderVisible,
	      _colors,
	      _labels,
	      _orientation,};
      return pds;
    } catch(IntrospectionException ex) {
      ex.printStackTrace();
      return null;
    }
  }

 /**
  * get the icon for a given type
  *
  * @param  iconKind (int) type of the requested icon
  * @return (Image) the image
  */
  public Image getIcon(int iconKind) {
    switch (iconKind) {
	    case BeanInfo.ICON_COLOR_16x16:
	      return iconColor16x16Filename != null ? loadImage(iconColor16x16Filename) : null;
	    case BeanInfo.ICON_COLOR_32x32:
	      return iconColor32x32Filename != null ? loadImage(iconColor32x32Filename) : null;
	    case BeanInfo.ICON_MONO_16x16:
	      return iconMono16x16Filename != null ? loadImage(iconMono16x16Filename) : null;
	    case BeanInfo.ICON_MONO_32x32:
	      return iconMono32x32Filename != null ? loadImage(iconMono32x32Filename) : null;
	  }
    return null;
  }

 /**
  * get additional bean information from superclass
  *
  * @return (BeanInfo[]) additional bean information from superclass
  */
  public BeanInfo[] getAdditionalBeanInfo() {
    Class superclass = beanClass.getSuperclass();
    try  {
      BeanInfo superBeanInfo = Introspector.getBeanInfo(superclass);
      return new BeanInfo[] { superBeanInfo };
    } catch(IntrospectionException ex) {
      ex.printStackTrace();
      return null;
    }
  }
}
