package openfuture.legend.test;

// imports
import java.util.*;
import javax.swing.*;
import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import openfuture.legend.*;

/**
 * Class LegendTestFrame is used to test the JLegend class
 *
 * @author  Markus Giebeler
 * @version $Revision: 1.0 $
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.<p>
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.<p>
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA<br>
 * http://www.gnu.org/copyleft/lesser.html"
 */
public class LegendTestFrame extends JFrame {
  JLegend legend = new JLegend();
  JPanel buttons = new JPanel();
  JButton doGirls = new JButton();
  JButton doBoys = new JButton();
  JCheckBox rowsOrColumns = new JCheckBox();
  JCheckBox fontSize = new JCheckBox();
  JCheckBox borderVisible = new JCheckBox();

  /** construct the frame */
  public LegendTestFrame(String[] arguments) {
    try  {
      jbInit();
    } catch(Exception e) {
      e.printStackTrace();
    }
    this.validate();
    //Fenster zentrieren
    Dimension sSize = Toolkit.getDefaultToolkit().getScreenSize();
    Dimension fSize = this.getSize();
    if (fSize.height > sSize.height) fSize.height = sSize.height;
    if (fSize.width  > sSize.width) fSize.width = sSize.width;
    this.setLocation((sSize.width - fSize.width) / 2, (sSize.height - fSize.height) / 2);
    // now complete initialization and display frame
    enableEvents(AWTEvent.WINDOW_EVENT_MASK);
    initialize();
    this.setVisible(true);
  }

  /** builds the view */
  private void jbInit() throws Exception  {
    this.setSize(new Dimension(410, 220));
    this.setTitle("Test Application for JLegend");
    doGirls.setText("girls");
    doGirls.addActionListener(new java.awt.event.ActionListener() {
      public void actionPerformed(ActionEvent e) {
        doGirls();
      }
    });
    doBoys.setText("boys");
    doBoys.addActionListener(new java.awt.event.ActionListener() {
      public void actionPerformed(ActionEvent e) {
        doBoys();
      }
    });
    rowsOrColumns.setText("rows");
    rowsOrColumns.addActionListener(new java.awt.event.ActionListener() {
      public void actionPerformed(ActionEvent e) {
        switchOrientation();
      }
    });
    fontSize.setText("small");
    fontSize.addActionListener(new java.awt.event.ActionListener() {
      public void actionPerformed(ActionEvent e) {
        switchFontSize();
      }
    });
    borderVisible.setSelected(true);
    borderVisible.setText("border");
    borderVisible.addActionListener(new java.awt.event.ActionListener() {
      public void actionPerformed(ActionEvent e) {
        switchBorderVisibility();
      }
    });
    this.getContentPane().add(legend, BorderLayout.CENTER);
    this.getContentPane().add(buttons, BorderLayout.SOUTH);
    buttons.add(doGirls, null);
    buttons.add(doBoys, null);
    buttons.add(rowsOrColumns, null);
    buttons.add(fontSize, null);
    buttons.add(borderVisible, null);
  }

  /** initializes the frame */
  public void initialize() {
    Color[] colors = {
      Color.red,
      Color.blue,
      Color.orange,
      Color.green,
      Color.yellow
    };
    //legend.setColors(colors);
    doGirls();
    switchOrientation();
    switchFontSize();
  }

  /** The main method */
  public static void main(String[] args) {
    try  {
      UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
    } catch(Exception e) {
    }
    new LegendTestFrame(args);
  }

  /** handle Window events */
  protected void processWindowEvent(WindowEvent e) {
    super.processWindowEvent(e);
    if(e.getID() == WindowEvent.WINDOW_CLOSING) {
      close();
    }
  }

  /** close frame */
  public void close() {
    System.exit(0);
  }

 /**
  * display legend for girls
  */
  protected void doGirls() {
    String[] labels = {
      "Anne",
      "Brbel",
      "Cornelia",
      "Doris",
      "Elfriede",
      "Frida",
      "Gertrude",
      "Henriette",
      "Iris",
      "Jaqueline",
      "Katharina",
      "Lara",
      "Monika",
      "Nora",
      "Olga",
      "Petra",
      "Roxanne",
      "Svenja",
      "Tanja",
      "Ute",
      "Vera",
      "Walburga",
      "Xantippe"
    };
    legend.setLabels(labels);
  }

 /**
  * display legend for boys
  */
  protected void doBoys() {
    String[] labels = {
      "Armin",
      "Bertram",
      "Carsten",
      "Dieter",
      "Emil",
      "Fritz",
      "Gerhard",
      "Heinrich",
      "Iwan",
      "Joachim",
      "Klaus",
      "Ludwig",
      "Markus",
      "Norbert",
      "Ottmar",
      "Peter",
      "Quirin",
      "Robert",
      "Stefan",
      "Thomas",
      "Uwe",
      "Volker",
      "Walter",
      "Xaver",
      "Zacharias"
    };
    legend.setLabels(labels);
  }

 /**
  * switch orientation of legend
  */
  protected void switchOrientation() {
    if(rowsOrColumns.isSelected()) {
      legend.setOrientation(JLegend.ROWS);
    } else {
      legend.setOrientation(JLegend.COLS);
    }
  }

 /**
  * switch font size of legend
  */
  void switchFontSize() {
    if(fontSize.isSelected()) {
      legend.setFont(new Font("Dialog", Font.PLAIN, 11));
    } else {
      legend.setFont(new Font("Dialog", Font.PLAIN, 12));
    }
  }

 /**
  * switch border visibility of legend
  */
  void switchBorderVisibility() {
    legend.setBorderVisible(borderVisible.isSelected());
  }

} // end of class LegendTestFrame

